@@ -129,71 +129,62 @@ class TRMaid(object):
             else:
                 self.msg('%.2f Gb free space left' % free_gb)
 
-        options = [
+        keys = [
             # Booleans
-            (bool, [
-                "alt-speed-enabled",
-                "alt-speed-time-enabled",
-                "blocklist-enabled",
-                "dht-enabled",
-                "download-queue-enabled",
-                "idle-seeding-limit-enabled",
-                "incomplete-dir-enabled",
-                "lpd-enabled",
-                "peer-port-random-on-start",
-                "pex-enabled",
-                "port-forwarding-enabled",
-                "queue-stalled-enabled",
-                "rename-partial-files",
-                "script-torrent-done-enabled",
-                "seed-queue-enabled",
-                "seedRatioLimited",
-                "speed-limit-down-enabled",
-                "speed-limit-up-enabled",
-                "start-added-torrents",
-                "trash-original-torrent-files",
-                "utp-enabled",
-            ]),
+            "alt-speed-enabled",
+            "alt-speed-time-enabled",
+            "blocklist-enabled",
+            "dht-enabled",
+            "download-queue-enabled",
+            "idle-seeding-limit-enabled",
+            "incomplete-dir-enabled",
+            "lpd-enabled",
+            "peer-port-random-on-start",
+            "pex-enabled",
+            "port-forwarding-enabled",
+            "queue-stalled-enabled",
+            "rename-partial-files",
+            "script-torrent-done-enabled",
+            "seed-queue-enabled",
+            "seedRatioLimited",
+            "speed-limit-down-enabled",
+            "speed-limit-up-enabled",
+            "start-added-torrents",
+            "trash-original-torrent-files",
+            "utp-enabled",
             # Doubles / Floats
-            (float, [
-                "seedRatioLimit",
-            ]),
+            "seedRatioLimit",
             # Integers
-            (int, [
-             "alt-speed-down",
-             "alt-speed-time-begin",
-             "alt-speed-time-day",
-             "alt-speed-time-end",
-             "alt-speed-up",
-             "cache-size-mb",
-             "download-queue-size",
-             "idle-seeding-limit",
-             "peer-limit-global",
-             "peer-limit-per-torrent",
-             "peer-port",
-             "queue-stalled-minutes",
-             "seed-queue-size",
-             "speed-limit-down",
-             "speed-limit-up",
-             ]),
+            "alt-speed-down",
+            "alt-speed-time-begin",
+            "alt-speed-time-day",
+            "alt-speed-time-end",
+            "alt-speed-up",
+            "cache-size-mb",
+            "download-queue-size",
+            "idle-seeding-limit",
+            "peer-limit-global",
+            "peer-limit-per-torrent",
+            "peer-port",
+            "queue-stalled-minutes",
+            "seed-queue-size",
+            "speed-limit-down",
+            "speed-limit-up",
             # Text / Strings
-            (None, [
-                "blocklist-url",
-                "download-dir",
-                "encryption",
-                "incomplete-dir",
-                "script-torrent-done-filename",
-            ])
+            "blocklist-url",
+            "download-dir",
+            "encryption",
+            "incomplete-dir",
+            "script-torrent-done-filename",
         ]
         session = self.conf['session']
-        for cast, keys in options:
-            for key in keys:
-                value = session.get(key)
-                if value is None:
-                    continue
-                current = args.get(key)
-                if current != value:
-                    req[key] = value
+        for key in keys:
+            value = session.get(key)
+            if value is None:
+                continue
+            current = args.get(key)
+            if current != value:
+                req[key] = value
 
         # blocklist
         blocklist_enabled = session.get('blocklist-enabled')
@@ -371,8 +362,8 @@ class TRMaid(object):
             if tor is None or tor['downloadDir'] != location:
                 req['location'] = location
 
-        if 'trackerAdd' in conf:
-            existing = map(lambda x:x['announce'], tor['trackers'])
+        if tor and 'trackerAdd' in conf:
+            existing = [x['announce'] for x in tor['trackers']]
             missing = [t for t in conf['trackerAdd'] if t not in existing]
             if missing:
                 req['trackerAdd'] = missing
